{% extends 'django_dzenlog/base.html' %}
{% load i18n dzenlog_tags lazy_tags %}

{% block head %}
    {{ block.super }}
    {% include 'django_dzenlog/feeds.html' %}
{% endblock %}

{% block content %}
    {% if object_list %}
        {% for object in object_list %}
            {% call object.render bytag_url=bytag_url,list_view=1,user=user %}
        {% endfor %}
    {% else %}
        <p>{% trans 'This blog is empty.' %}</p>
    {% endif %}
{% endblock %}
